@@ -19,9 +19,6 @@
 
 #include <cinttypes>
 
-#include <ace/INET_Addr.h>
-#include <ace/OS.h>
-
 #include <geode/AuthInitialize.hpp>
 #include <geode/SystemProperties.hpp>
 
@@ -161,11 +158,10 @@ bool TcrConnection::initTcrConnection(
   if (endpointObj->getPoolHADM()) {
     ClientProxyMembershipID* memId =
         endpointObj->getPoolHADM()->getMembershipId();
-    uint32_t memIdBufferLength;
-    auto memIdBuffer = memId->getDSMemberId(memIdBufferLength);
+    const auto& dsMemberId = memId->getDSMemberId();
     handShakeMsg.writeBytes(
-        reinterpret_cast<int8_t*>(const_cast<char*>(memIdBuffer)),
-        memIdBufferLength);
+        reinterpret_cast<const uint8_t*>(dsMemberId.c_str()),
+        static_cast<int32_t>(dsMemberId.size()));
   } else {
     ACE_TCHAR hostName[256];
     ACE_OS::hostname(hostName, sizeof(hostName) - 1);
@@ -180,13 +176,12 @@ bool TcrConnection::initTcrConnection(
     auto&& durableTimeOut = sysProp.durableTimeout();
 
     // Write ClientProxyMembershipID serialized object.
-    uint32_t memIdBufferLength;
     auto memId = cacheImpl->getClientProxyMembershipIDFactory().create(
         hostName, driver, hostPort, durableId.c_str(), durableTimeOut);
-    auto memIdBuffer = memId->getDSMemberId(memIdBufferLength);
+    const auto& dsMemberId = memId->getDSMemberId();
     handShakeMsg.writeBytes(
-        reinterpret_cast<int8_t*>(const_cast<char*>(memIdBuffer)),
-        memIdBufferLength);
+        reinterpret_cast<const uint8_t*>(dsMemberId.c_str()),
+        static_cast<int32_t>(dsMemberId.size()));
   }
   handShakeMsg.writeInt(static_cast<int32_t>(1));
 
@@ -1238,8 +1233,9 @@ bool TcrConnection::hasExpired(const std::chrono::milliseconds& expiryTime) {
   if (expiryTime <= std::chrono::milliseconds::zero()) {
     return false;
   }
-
-  return (clock::now() - m_creationTime) > expiryTime;
+  auto variadicExpiryTime =
+      expiryTime + (expiryTime * m_expiryTimeVariancePercentage) / 100;
+  return (clock::now() - m_creationTime) > variadicExpiryTime;
 }
 
 bool TcrConnection::isIdle(const std::chrono::milliseconds& idleTime) {
