@@ -20,8 +20,6 @@
 #include <algorithm>
 #include <thread>
 
-#include <ace/INET_Addr.h>
-
 #include <geode/AuthInitialize.hpp>
 #include <geode/PoolManager.hpp>
 #include <geode/ResultCollector.hpp>
@@ -43,15 +41,7 @@ namespace apache {
 namespace geode {
 namespace client {
 
-/* adongre
- * CID 28730: Other violation (MISSING_COPY)
- * Class "GetAllWork" owns resources that are managed in its constructor and
- * destructor but has no user-written copy constructor.
- * FIX : Make the class NonCopyable
- */
-class GetAllWork : public PooledWork<GfErrType>,
-                   private NonCopyable,
-                   private NonAssignable {
+class GetAllWork : public PooledWork<GfErrType> {
   ThinClientPoolDM* m_poolDM;
   std::shared_ptr<BucketServerLocation> m_serverLocation;
   TcrMessage* m_request;
@@ -68,6 +58,8 @@ class GetAllWork : public PooledWork<GfErrType>,
   const std::shared_ptr<Serializable>& m_aCallbackArgument;
 
  public:
+  GetAllWork(const GetAllWork&) = delete;
+  GetAllWork& operator=(const GetAllWork&) = delete;
   GetAllWork(
       ThinClientPoolDM* poolDM, const std::shared_ptr<Region>& region,
       const std::shared_ptr<BucketServerLocation>& serverLocation,
@@ -1974,11 +1966,8 @@ GfErrType ThinClientPoolDM::sendRequestToEP(const TcrMessage& request,
 }
 
 TcrEndpoint* ThinClientPoolDM::addEP(ServerLocation& serverLoc) {
-  std::string serverName = serverLoc.getServerName();
-  int port = serverLoc.getPort();
-  char endpointName[100];
-  std::snprintf(endpointName, 100, "%s:%d", serverName.c_str(), port);
-
+  const auto endpointName =
+      serverLoc.getServerName() + ":" + std::to_string(serverLoc.getPort());
   return addEP(endpointName);
 }
 
@@ -1990,7 +1979,7 @@ TcrEndpoint* ThinClientPoolDM::addEP(const std::string& endpointName) {
     LOGFINE("Created new endpoint %s for pool %s", endpointName.c_str(),
             m_poolName.c_str());
     ep = createEP(endpointName.c_str());
-    if (m_endpoints.emplace(endpointName, ep).second) {
+    if (!m_endpoints.emplace(endpointName, ep).second) {
       LOGERROR("Failed to add endpoint %s to pool %s", endpointName.c_str(),
                m_poolName.c_str());
     }
