@@ -23,9 +23,6 @@
 #include <mutex>
 #include <unordered_map>
 
-#include <ace/RW_Thread_Mutex.h>
-#include <ace/Task.h>
-
 #include <geode/ResultCollector.hpp>
 #include <geode/internal/functional.hpp>
 
