@@ -17,9 +17,11 @@
 r301 %r{/releases/latest/javadoc/(.*)}, 'https://geode.apache.org/releases/latest/javadoc/$1'
 r302 %r{/cppdocs/(.*)}, 'https://geode.apache.org/releases/latest/cppdocs/$1'
 r302 %r{/dotnetdocs/(.*)}, 'https://geode.apache.org/releases/latest/dotnetdocs/$1'
+r302 %r{/cppapiref/(.*)}, 'https://geode.apache.org/releases/latest/cppdocs/$1'
+r302 %r{/dotnetapiref/(.*)}, 'https://geode.apache.org/releases/latest/dotnetdocs/$1'
 
 # Links to User Guides #
-rewrite '/', '/docs/geode-native/dotnet/112/about-client-users-guide.html'
-rewrite '/index.html', '/docs/geode-native/dotnet/112/about-client-users-guide.html'
+rewrite '/', '/docs/geode-native/dotnet/113/about-client-users-guide.html'
+rewrite '/index.html', '/docs/geode-native/dotnet/113/about-client-users-guide.html'
 r301 %r{/serverman/(.*)}, 'https://geode.apache.org/docs/guide/112/$1'
 r301 %r{/geodeman/(.*)}, 'https://geode.apache.org/docs/guide/112/$1'
